@@ -4,11 +4,11 @@ use strict;
 
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 #use DateTime 0.08;
 use DateTime::Duration;
-use DateTime::Language;
+use DateTime::Locale;
 use Params::Validate qw/validate SCALAR OBJECT/;
 
 sub _floor {
@@ -28,24 +28,23 @@ use overload ( 'fallback' => 1,
                '+' => '_add_overload',
              );
 
-# Copied from DateTime.pm
 {
-    my $DefaultLanguage;
-    sub DefaultLanguage {
+    my $DefaultLocale;
+    sub DefaultLocale {
         my $class = shift;
 
         if (@_) {
             my $lang = shift;
 
-            DateTime::Language->load($lang);
+            DateTime::Locale->load($lang);
 
-            $DefaultLanguage = $lang;
+            $DefaultLocale = $lang;
         }
 
-        return $DefaultLanguage;
+        return $DefaultLocale;
     }
 }
-__PACKAGE__->DefaultLanguage('French');
+__PACKAGE__->DefaultLocale('French');
 
 sub new {
     my $class = shift;
@@ -53,13 +52,15 @@ sub new {
                       { year  => {type => SCALAR},
                         month => {type => SCALAR, default => 1},
                         day   => {type => SCALAR, default => 1},
-                        language  => { type => SCALAR | OBJECT,
-                                       default => $class->DefaultLanguage },
+                        rd_secs   => { type => SCALAR, default => 0},
+                        rd_nano   => { type => SCALAR, default => 0},
+                        locale  => { type => SCALAR | OBJECT,
+                                       default => $class->DefaultLocale },
                       } );
 
     my $self = bless \%p, $class;
-    $self->{language} = DateTime::Language->new(language => $p{language})
-        unless (ref $self->{language});
+    $self->{locale} = DateTime::Locale->load($p{locale})
+        unless (ref $self->{locale});
 
     return $self;
 }
@@ -77,11 +78,11 @@ sub set
                       { year     => { type => SCALAR, optional => 1 },
                         month    => { type => SCALAR, optional => 1 },
                         day      => { type => SCALAR, optional => 1 },
-                        language => { type => SCALAR | OBJECT, optional => 1 },
+                        locale => { type => SCALAR | OBJECT, optional => 1 },
                       } );
 
-    if (exists $p{language} && ! ref $p{language}) {
-        $p{language} = DateTime::Language->new(language => $p{language})
+    if (exists $p{locale} && ! ref $p{locale}) {
+        $p{locale} = DateTime::Locale->load($p{locale})
     }
 
     $self->{$_} = $p{$_} for keys %p;
@@ -102,7 +103,7 @@ sub truncate {
     return $self;
 }
 
-sub language { $_[0]->{language} }
+sub locale { $_[0]->{locale} }
 
 sub is_leap_year {
     my $self = shift;
@@ -160,11 +161,11 @@ sub day_name {
 
     if ($self->{day} == 29) {
         my $name = 'hunyadi';
-        my $n = $self->{language}->day_names->[0];
+        my $n = $self->{locale}->day_names->[0];
         $name = ucfirst $name if $n eq ucfirst $n;
         return $name;
     } else {
-        return $self->{language}->day_names->[($self->day_of_week_0 || 7)-1];
+        return $self->{locale}->day_names->[($self->day_of_week_0 || 7)-1];
     }
 }
 
@@ -270,7 +271,7 @@ sub last_day_of_month {
     my %p = validate( @_,
                       { year   => { type => SCALAR },
                         month  => { type => SCALAR },
-                        language  => { type => SCALAR | OBJECT, optional => 1 },
+                        locale  => { type => SCALAR | OBJECT, optional => 1 },
                       }
                     );
     $p{day} = 29;
@@ -301,15 +302,15 @@ sub utc_rd_values {
              _floor(($cyear+72)/100) +  # century years
              _floor(($cyear+272)/400 ) +
              + ($month - 1) * 28 + $day;
-    return ($rd, 0);
+    return ($rd, $self->{rd_secs}, $self->{rd_nano});
 }
 
 sub utc_rd_as_seconds {
     my $self = shift;
-    my ($rd_days, $rd_secs) = $self->utc_rd_values;
+    my ($rd_days, $rd_secs, $rd_nano) = $self->utc_rd_values;
 
     if (defined $rd_days) {
-        return $rd_days*24*60*60 + $rd_secs;
+        return $rd_days*24*60*60 + $rd_secs + $rd_nano * 1e-9;
     } else {
         return undef;
     }
@@ -321,20 +322,21 @@ sub from_object {
                       { object => { type => OBJECT,
                                     can => 'utc_rd_values',
                                   },
-                        language => { type => SCALAR | OBJECT,
-                                      default => $class->DefaultLanguage },
+                        locale => { type => SCALAR | OBJECT,
+                                      default => $class->DefaultLocale },
                       },
                        );
 
     $p{object} = $p{object}->clone->set_time_zone( 'floating' )
                                 if $p{object}->can( 'set_time_zone' );
 
-    my ( $rd_days, $rd_secs ) = $p{object}->utc_rd_values;
+    my ( $rd_days, $rd_secs, $rd_nano ) = $p{object}->utc_rd_values;
 
     my ($y, $m, $d) = $class->_rd2ymd( $rd_days );
 
     return $class->new( year => $y, month => $m, day => $d,
-                        language => $p{language} );
+                        rd_secs => $rd_secs||0, rd_nano => $rd_nano||0,
+                        locale => $p{locale} );
 }
 
 sub _rd2ymd {
@@ -382,8 +384,8 @@ sub from_epoch {
     my $class = shift;
     my %p = validate( @_,
                       { epoch => { type => SCALAR },
-                        language => { type => SCALAR | OBJECT,
-                                      default => $class->DefaultLanguage },
+                        locale => { type => SCALAR | OBJECT,
+                                      default => $class->DefaultLocale },
                       }
                     );
 
@@ -392,7 +394,7 @@ sub from_epoch {
     my ($y, $m, $d) = $class->_rd2ymd( $rd );
 
     return $class->new( year => $y, month => $m, day => $d,
-                        language => $p{language} );
+                        locale => $p{locale} );
 }
 
 sub now { shift->from_epoch( epoch => (scalar time), @_ ) }
@@ -935,14 +937,17 @@ same name.
 =item * new( ... )
 
 This class method accepts parameters for each date and time component:
-"year", "month", "day".  Additionally, it accepts a "language"
+"year", "month", "day".  Additionally, it accepts a "locale"
 parameter.
 
+The "rd_secs" parameter is also accepted. This parameter is only useful
+in conversions to other calendars; this calendar does not use its value.
+
 =item * from_epoch( epoch => $epoch, ... )
 
 This class method can be used to construct a new object from
 an epoch time instead of components.  Just as with the C<new()>
-method, it accepts a "language" parameter.
+method, it accepts a "locale" parameter.
 
 =item * now( ... )
 
@@ -955,9 +960,12 @@ This class method can be used to construct a new object from
 any object that implements the C<utc_rd_values()> method.  All
 C<DateTime::Calendar> modules must implement this method in order to
 provide cross-calendar compatibility.  This method accepts a
-"language" parameter.
+"locale" parameter.
 
-The time part of $object is ignored.
+The time part of $object is stored, and will only be used if the created
+object is converted to another calendar. Only the date part of $object
+is used to calculate the Pataphysical date. This calculation is based on
+the local time and date of $object.
 
 =item * last_day_of_month( ... )
 
@@ -1075,7 +1083,7 @@ imaginary date.
 =item * set( .. )
 
 This method can be used to change the local components of a date time,
-or its language.  This method accepts any parameter allowed by the
+or its locale.  This method accepts any parameter allowed by the
 C<new()> method.
 
 =item * truncate( to => ... )
